<?php

namespace App\Modules\Admin\Controllers\Admin;

use App\Base\BaseController;
use App\Models\Goods\Category;
use App\Modules\Admin\Services\CategoryService;
use Faker\Provider\Image;

class CategoryController extends BaseController
{
    /** @var CategoryService $service */
    protected $service;

    public function __construct(CategoryService $authService)
    {
        $this->service = $authService;
    }

    public function paginate()
    {
        $params = $this->valid([
            "name" => "",
            "level" => "",
            "page_size" => "",
        ]);
        return $this->ok($this->service->paginate($params));
    }

    protected function mockCategory()
    {
        return [
            "id" => 1,
            "name" => "分类名称",
            "thumb" => "xx" . Image::imageUrl(),
            "level" => 1,
            "parent_id" => 1,
            "parent_name" => "上级名称",
            "child_category_count" => 1,
            "child_goods_count" => 1,
            "weight" => 1,
            "index_weight" => 1,
            "category_weight" => 1,
            "search_weight" => 1,
        ];
    }

    public function store()
    {
        $params = $this->valid([
            "id" => "int",
            "name" => "required|max:255",
            "thumb" => "url",
            "weight" => "int",
            "parent_id" => "int",
            "index_weight" => "int",
            "category_weight" => "int",
            "search_weight" => "int",
        ]);
        return $this->ok($this->service->store($params)->format());
    }

    public function info()
    {
        $data = $this->valid([
            "id" => "required",
        ]);
        /** @var Category $model */
        $model = Category::findOrFail($data['id']);
        return $this->ok($model->format());
    }

    public function del()
    {
        $data = $this->valid([
            "id" => "required",
        ]);

        return $this->ok($this->service->del($data));
    }

}
