<?php

namespace App\Modules\Admin\Controllers\Admin;

use App\Base\BaseController;
use App\Models\Goods\Goods;
use App\Modules\Admin\Services\GoodsService;
use App\Modules\Admin\Services\SpecService;

class GoodsController extends BaseController
{
    protected SpecService $specService;
    protected GoodsService $service;

    public function __construct(GoodsService $service, SpecService $authService)
    {
        $this->specService = $authService;
        $this->service = $service;
    }

    public function paginate()
    {
        $params = $this->valid([
            "page_size" => "",
            "name" => "",
            "status" => "",
        ]);
        return $this->ok($this->service->paginate($params));
    }

    public function changeStatus()
    {
        $id = request()->input("id", 0);
        $m = Goods::findOrFail($id);
        if ($m->status == Goods::STATUS_OK) {
            $m->status = Goods::STATUS_OFF;
        } else {
            $m->status = Goods::STATUS_OK;
        }
        $m->save();
        return $this->ok();
    }

    public function makeSkuTable()
    {
        $data = $this->valid([
            "spec_list" => "required|array",
        ]);

        return $this->ok([
            "sku_table" => $this->specService->cartesian($data['spec_list']),
        ]);

    }

    public function info()
    {
        $params = $this->valid([
            "id" => "required",
        ]);
        return $this->ok($this->service->info($params));
    }

    public function store()
    {
        $params = $this->valid([
            "id" => "int",
            "name" => "required|max:50",
            "image_list" => "required|array",
            "category" => "required|array",
            "spec" => 'required|array',
            "sku" => 'required|array',
            'weight' => "int",
            "desc_html" => "",
            "spec_attr_html" => "",
            "faq_html" => "",
        ]);
        return $this->ok($this->service->store($params));
    }

    public function specPaginate()
    {
        $data = $this->valid([
            "name" => "",
            "status" => "",
            "page_size" => "",
        ]);

        return $this->ok($this->specService->paginate($data));
    }

    public function specStore()
    {
        $params = $this->valid([
            "id" => "",
            "name" => "required",
            "attr" => "array",
            "index_weight" => "int",
            "category_weight" => "int",
            "search_weight" => "int",
            "is_custom" => "int",
        ]);

        return $this->ok($this->specService->specStore($params));
    }

    public function specInfo()
    {
        $params = $this->valid([
            "id" => "required",
        ]);

        return $this->ok($this->specService->specInfo($params));
    }

    public function specDelete()
    {
        $data = $this->valid([
            "id" => "required",
        ]);

        return $this->ok($this->specService->specDelete($data));
    }
}
